summaryrefslogtreecommitdiff
path: root/sw/source/filter/xml/XMLRedlineImportHelper.hxx
diff options
context:
space:
mode:
authorDaniel Vogelheim <dvo@openoffice.org>2001-05-02 15:26:26 +0000
committerDaniel Vogelheim <dvo@openoffice.org>2001-05-02 15:26:26 +0000
commit93dca26e27a4bc51ac873777ef8b134283ae9f71 (patch)
tree480f337d0e10e8a9302d2377e5f8806219644125 /sw/source/filter/xml/XMLRedlineImportHelper.hxx
parentbdf9f21f53e5d5aa2e105cdec4d233deec5f5e1b (diff)
added redline password protection
moved redlining enabled flag from view settings to redline element
Diffstat (limited to 'sw/source/filter/xml/XMLRedlineImportHelper.hxx')
-rw-r--r--sw/source/filter/xml/XMLRedlineImportHelper.hxx44
1 files changed, 33 insertions, 11 deletions
diff --git a/sw/source/filter/xml/XMLRedlineImportHelper.hxx b/sw/source/filter/xml/XMLRedlineImportHelper.hxx
index 44949f71c3a8..da74c0b45bd1 100644
--- a/sw/source/filter/xml/XMLRedlineImportHelper.hxx
+++ b/sw/source/filter/xml/XMLRedlineImportHelper.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: XMLRedlineImportHelper.hxx,v $
*
- * $Revision: 1.3 $
+ * $Revision: 1.4 $
*
- * last change: $Author: dvo $ $Date: 2001-03-27 09:37:50 $
+ * last change: $Author: dvo $ $Date: 2001-05-02 16:26:26 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -70,6 +70,10 @@
#include <com/sun/star/uno/Reference.h>
#endif
+#ifndef _COM_SUN_STAR_UNO_SEQUENCE_H_
+#include <com/sun/star/uno/Sequence.h>
+#endif
+
#ifndef _COM_SUN_STAR_UTIL_DATETIME_HPP_
#include <com/sun/star/util/DateTime.hpp>
#endif
@@ -102,28 +106,36 @@ class XMLRedlineImportHelper
const ::rtl::OUString sInsertion;
const ::rtl::OUString sDeletion;
const ::rtl::OUString sFormatChange;
+ const ::rtl::OUString sShowChanges;
+ const ::rtl::OUString sRecordChanges;
+ const ::rtl::OUString sRedlineProtectionKey;
RedlineMapType aRedlineMap;
- /// redline mode before the import (to be restored after import)
- sal_uInt16 eSavedRedlineMode;
- sal_Bool bSavedRedlineMode; /// validity-flag for eSavedRedlineMode
-
/// if sal_True, no redlines should be inserted into document
/// (This typically happen when a document is loaded in 'insert'-mode.)
sal_Bool bIgnoreRedlines;
- /// save the document (for destructor)
- SwDoc* pSaveDoc;
+ /// save information for saving and reconstruction of the redline mode
+ ::com::sun::star::uno::Reference<
+ ::com::sun::star::beans::XPropertySet> xModelPropertySet;
+ ::com::sun::star::uno::Reference<
+ ::com::sun::star::beans::XPropertySet> xImportInfoPropertySet;
+ sal_Bool bShowChanges;
+ sal_Bool bRecordChanges;
+ ::com::sun::star::uno::Sequence<sal_Int8> aProtectionKey;
public:
XMLRedlineImportHelper(
sal_Bool bIgnoreRedlines, /// ignore redlines mode
- /// model (for saving the redline mode)
+
+ // property sets of model + import info for saving + restoring the
+ // redline mode
+ const ::com::sun::star::uno::Reference<
+ ::com::sun::star::beans::XPropertySet> & rModel,
const ::com::sun::star::uno::Reference<
- ::com::sun::star::frame::XModel> & rModel,
- sal_Bool bPreserveRedlineMode);
+ ::com::sun::star::beans::XPropertySet> & rImportInfoSet );
virtual ~XMLRedlineImportHelper();
/// create a redline object
@@ -170,6 +182,16 @@ public:
::com::sun::star::uno::Reference<
::com::sun::star::text::XTextRange> & rRange);
+ /// set redline mode: show changes
+ void SetShowChanges( sal_Bool bShowChanges );
+
+ /// set redline mode: record changes
+ void SetRecordChanges( sal_Bool bRecordChanges );
+
+ /// set redline protection key
+ void SetProtectionKey(
+ const ::com::sun::star::uno::Sequence<sal_Int8> & rKey );
+
private:
inline sal_Bool IsReady(RedlineInfo* pRedline);